#
# spec file for package vym
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           vym
Version:        2.9.28
Release:        1.5
Summary:        Tool to generate and manipulate thought maps
License:        GPL-2.0-only
Group:          Productivity/Office/Other
URL:            http://www.insilmaril.de/vym/index.html
Source0:        %{name}-%{version}.tar.bz2
Source1:        debian.dirs
Source2:        debian.docs
Source3:        makedist.config

BuildRequires:  cmake
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(dbus-1)

BuildRequires:  cmake(Qt5Core) >= 5.15.2
BuildRequires:  cmake(Qt5DBus)
BuildRequires:  cmake(Qt5LinguistTools)
BuildRequires:  cmake(Qt5Network)
BuildRequires:  cmake(Qt5PrintSupport)
BuildRequires:  cmake(Qt5Script)
BuildRequires:  cmake(Qt5Svg)
BuildRequires:  cmake(Qt5Xml)

%if 0%{?suse_version}
BuildRequires:  update-desktop-files
%endif

Requires:       unzip
Requires:       zip
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
VYM (View Your Mind) is a tool to generate and manipulate maps which
show thoughts. Such maps can help improve creativity and effectivity.
They can be used for time management, to organize tasks, to get an
overview over complex contexts, to sort ideas etc.

%prep
%setup -q

%build
%global cmake_options \\\
    -DCMAKE_INSTALL_DATAROOTDIR="share/vym" \\\
    -DCMAKE_INSTALL_MANDIR="%{_mandir}/man1" \\\
    -DCMAKE_INSTALL_DOCDIR="%{_defaultdocdir}/%{name}"

%cmake %{cmake_options}
%cmake_build

%install
%cmake_install

%if 0%{?suse_version}
%suse_update_desktop_file -i vym Office ProjectManagement
%endif

# Make scripts executable already installed with cmake above
chmod 755 %{buildroot}%{_datadir}/%{name}/scripts/vivym
chmod 755 %{buildroot}%{_datadir}/%{name}/scripts/vym-addmail.rb

%post
if test -x usr/bin/update-mime-database ; then
  usr/bin/update-mime-database usr/share/mime >/dev/null
fi

%files
%defattr(-,root,root)
%{_datadir}/applications/*

# Directories can be owned by multiple packages:
%dir %{_datadir}/icons/hicolor/48x48
%dir %{_datadir}/icons/hicolor/48x48/apps
%dir %{_datadir}/icons/hicolor/48x48/mimetypes

%{_datadir}/icons/*/*/*/*.*
%{_bindir}/vym
%{_datadir}/vym

%doc %{_docdir}/%{name}
%{_mandir}/*/*
%{_datadir}/mime/packages/vym.xml

%changelog
* Tue Jul 16 2024 jun wang <jgwang@suse.com>
- Update to version 2.9.28
  * Add a README.source file to describe the tarball creation.
  * Remove desktop.patch - applied upstream.
  * Refresh cmake-installs.patch.
  * Remove debian/vym.links, mimetype icon link is created
    by cmake.
- Other changes since 2.9.2
  * Add myself as Uploader.
  * Replace cdbs by debhelper as the Debian build helper.
  * Drop pro-file.patch - building with cmake now.
  * Refresh do-not-phone-home.patch.
  * Ship upstream man 1 vym.
  * Drop debian/menu.
  * Update debian/copyright.
  * Add a mimetype icon for the hicolor default theme.
  * Add Rules-Requires-Root set to no.
  * Add Vcs information to debian/control.
  * Raise Standards-Version to 4.7.0.
  * Delete old desktop file shipped in debian/.
  * Add desktop.patch to pass %%F in the Exec setting and add
    keywords.
  * Add doc-base registration for the user manual.
  * Add cmake-installs.patch to adjust documentation install
    folder.
  * Adjust watch file to query github API and change to version 4.
  * Include release-notes-2.9.md in the package docs.
  * Feature: Support multiple Jira instances with specific
    authentication methods
  * Feature: Floppy disk icon for unsaved maps better visible,
    if active
  * Feature: Upload images also for new Confluence pages
  * Feature: New commands to control visuals of selection box
  * Feature: added script to set colors of selection box for dark theme
    demos/scripts/setSelectionBoxDarkTheme.vys
    cannot understand every of the newer elements and .
  * Feature: Center on selection and fit to view with
    Key_Period + Key_Shift
  * Feature: Delete vymLink with Ctrl-Shift click
  * Feature: Scale pasted images to 300px width
  * Feature: Define pen color, width and brush for selection box
    setSelectionPenColor
    setSelectionPenWidth
    setSelectionBrushColor
  * Feature: Option to 'never' use dark theme
  * Feature: Support Personal Access Tokens for Jira and Confluence
  * Feature: Improved animated centering on selection
    (Shortcut: Key_Period)
  * Feature: For multiple selected items show count in status line
  * Feature: Scale images on the fly
  * Bugfix: Creating Confluence page without attachments
  * Bugfix: Icon and status of view icons
  * Bugfix: disabled all icons when no map is available.
  * Bugfix: Fixed layout of dialog for Confluence export
  * Bugfix: Improved adding new branches at border of current scene
  * Bugfix: Urls and VymLinks shown again in statusBar
  * Bugfix: Wrong positon of selection box of xlinks control points,
    resulting in crazy scrolling, when control point is selected.
  * Bugfix: #79 quell linking error (#79)
  * Bugfix: Set selection background color in TreeEditor
  * Bugfix: Also center on selected branch when using HeadingEditor
    while editing a heading
  * Bugfix: Save colors of headings
  * Bugfix: Editing long plainText headings might open
    HeadingEditor
  * Bugfix: #65 and #71 Colors in NoteEditor with RichText
  * Bugfix: #76 Editing heading of zoomed in view causes panning
  * Bugfix: When zooming in/out using mouse wheel don't change
    rotation
  * Bugfix: Background colors in HeadingEditor
  * Bugfix: #40 Editing PlainText headings with linebreaks
  * Bugfix: #75 TreeEditor and Linebreaks in headings
  * Bugfix: #73 Default maps should not have word default in
    MapCenter
  * Bugfix: #72 Improved support to load new default maps
  * Bugfix: #74 HTML export uses word wrap for PlainText notes
  * Bugfix: Update HeadingEditor for RichText heading, when frame
    background changes
  * Bugfix: Update color and heading of HeadingEditor
  * Bugfix: #70 HeadingEditor doesn't use map background when
    switching on RichText mode
  * Bugfix: #70 settings override macroPath, if local option is
    used "-l"
  * Bugfix: #68 HeadingEditor doesn't update after in MapEditor
  * Bugfix: Consider zoomFactor after load when scrolling to
    selection
  * Bugfix: Set color and width of legacy xlink
  * Change: Use Control modifier instead of Shift to only move
    MapCenter
  * Change: Compatibility with 2.9.514: Some elements can be read,
    even if vym
* Thu Apr 13 2023 Uwe Drechsel <vym@insilmaril.de>
- Update to upstream Version 2.9.2
- Bugfix: #64 Potential loss of data when parsing (very) old maps
- Other changes since 2.8.43:
    Bugfix: Read <note> with inline HTML correctly
    Bugfix: Finding translations on Windows
    Bugfix: #52 Saving part of map overwrites original map
    Bugfix: Read map attributes for default map
    Bugfix: #48 lockfile cannot be renamed on Windows
    Bugfix: Create translation files during build
    Bugfix: Create *.qm files during build for translations
    Feature: Settings dialog for dark theme support
    Feature: Increase max. number of recent maps to 20
* Wed Mar 22 2023 Uwe Drechsel <vym@insilmaril.de>
- Update to upstream Version 2.9.0
* Fri Oct 28 2022 Uwe Drechsel <vym@insilmaril.de>
- Update to upstream Version 2.8.43
- Bugfix for setting URL after retrieving data from Jira
* Thu Sep  8 2022 Uwe Drechsel <vym@insilmaril.de>
- Update to upstream version 2.8.41
- bugfixes, some features
- switch to cmake
* Tue Aug 17 2021 Uwe Drechsel <vym@insilmaril.de>
- Update to upstream version 2.8.8 (Bugfixes)
  In 2.8.0 vymBaseDir was not set correctly, which made most of vym
  unusable. See also https://github.com/insilmaril/vym/issues/14
* Thu Apr 15 2021 Uwe Drechsel <vym@insilmaril.de>
- Update to upstream version 2.8.0 (bugfixes and features)
* Mon Apr 15 2019 Jan Engelhardt <jengelh@inai.de>
- Generalize description. Trim trivial name repetition in summary.
* Mon Apr 15 2019 Uwe Drechsel <vym@insilmaril.de>
- Update to upstream 2.7.0 (bugfix and features)
* Sat Sep 17 2016 vym@insilmaril.de
- Update to upstream 2.6.0 (bugfix and languages added)
* Tue Aug 16 2016 vym@insilmaril.de
- Update to upstream 2.5.21 (Prerelease of 2.6.0)
- 68 bugfixes / 17 features added
* Tue Jun 21 2016 vym@insilmaril.de
- Update to upstream 2.5.4
- Remove vym-2.5.0-gcc6.patch again, not required
* Mon Jun 20 2016 i@marguerite.su
- add patch vym-2.5.0-gcc6.patch
  * no known conversion for argument 2 from bool to QString,
    actually the second QString was skipped, the bool value
    was the 3rd argument.
* Wed Oct 28 2015 vym@insilmaril.de
- Version 2.5.0
- Bugfix: Update recent maps menu after loading of map
- Bugfix: Empty window with update information on startup
* Tue Aug 25 2015 vym@insilmaril.de
- Version 2.4.8
* Mon Aug 24 2015 vym@insilmaril.de
- Version 2.4.7
* Tue Aug 18 2015 vym@insilmaril.de
- Version 2.4.6
* Fri Jul 24 2015 vym@insilmaril.de
- Version 2.4.5
* Sun May 17 2015 vym@insilmaril.de
- Version 2.4.3
* Tue May  5 2015 vym@insilmaril.de
- Version 2.4.2
* Mon Oct 27 2014 uwedr@suse.de
- Version 2.4.0
- Update to Qt 5
- Preliminary support of checking for updates
  and release notes online
* Mon Oct 27 2014 uwedr@suse.de
- Version 2.3.24
- Added updated translation by Pavel Fric
- When changing sleep time of finished task, also set task state to 'WIP'.
- Bugfix: Restore saved toolbar configuration
- Bugfix: #65 Missing break statemens in parser
* Fri Sep  5 2014 chris@computersalat.de
- Version 2.3.22
- French translation by Marc Sert
- Feature: Improved xlinks with arrowheads
- Feature: Task priority increases slightly with age of tasks
- Some more includes to ease Debian packaging (by p0llux)
- Patch to allow hardening in Debian by p0llux
- update to 2.3.24
  * Added updated translation by Pavel Fric
  * Bugfix: Restore saved toolbar configuration
  - 2.3.23
  * When changing sleep time of finished task, also set task state to
    'WIP'
  * Bugfix: #65 Missing break statements in parser
  - 3.2.22
  * Set (and read) default style for ends of xlinks
  * Tests for XLinks
  * Fixing the test script
  * Undo/redo for modifying xlinks
  * Removed some debugging output
  * Cleaned up a bit
  * Commands to set xlinkstyle (begin and end)
  * Fixed graphical glitch during creation of XLink
  * Toggling arrowheads for ends of xlink in dialog
  * Use Arrows also for lines to control points of xlink
  * Hide arrows of xlinks when scrolling
  * Draw arrow for begin and end of xlink
  * Initial work on arrows for xlinks
  * Priority increases slightly with age of tasks
  - 3.2.21
  * Some more includes to ease Debain packaging (by p0llux)
  * Patch to allow hardening in Debian by p0llux
  * Fixed project file
* Fri Sep 13 2013 uwedr@suse.de
- Version 2.3.20
- Bugfix: #45 Don't grab keyboard while editing heading
- Bugfix: #56 Default pdf viewer for Windows
- Bugfix: #58 Notes break if they only contain whitespace
- Bugfix: Added missing note for automated test to git
- Bugfix: Building on windows (Patrick Spendrin)
- Bugfix: Considering frame sizes
- Bugfix: Creating notes by piping mails (e.g. from mutt)
- Bugfix: Default size for PDF Export: A3
- Bugfix: Delete slide deleted 2 slides at once
- Bugfix: Deselect task in TaskEditor, if no task selected in MapEditor
- Bugfix: Don't create duplicate UUIds while pasting
- Bugfix: Double click branch while editing heading copies heading
- Bugfix: Editor key shortcuts for Save (Ctrl + S)
- Bugfix: Flags position after setting task sleep
- Bugfix: HTML export
- Bugfix: HTML export settings (Re-added after merge)
- Bugfix: Include images correctly in frame
- Bugfix: LastExport for AO, ASCII, OrgMode, LaTeX
- Bugfix: Move images when moving MCO
- Bugfix: open LineEdit for heading at heading, not topLeft of BBox
- Bugfix: (Regression) creating XLinks
- Bugfix: Releasing image triggers reposition now
- Bugfix: Removed unneeded output in testscript
- Bugfix: Reposition note flag after updating note
- Bugfix: Reposition note flag after updating note
- Bugfix: Reuse previous HTML export settings
- Bugfix: Stretch width of last column in task editor
- Bugfix: Toggling task flags
- Bugfix: Undo of deleting mapcenter
- Bugfix: Vertical aligment of children
- Feature: 12 additional macros using Shift + Fn
- Feature: Alternative shortcut for Find: Key_Slash
- Feature: New command selectParent
- Feature: Open vymLinks in background tab
- Feature: Quit immediatly after listing options -s or -sl
- Feature: Shortcut in scripteditor to "save to selected slide"
- Feature: Show parent of a task in taskeditor
- Feature: Template for creating snapshot in slideeditor
- Feature: unselectAll for scripts
* Tue Jul 16 2013 uwedr@suse.de
- Version 2.3.19
- Feature: optimizations in layout enginge
- Feature: Alternative shortcut for Find: Key_Slash
- Feature: unselectAll for scripts
- Feature: New command selectParent
- Feature: Quit immediatly after listing options -s or -sl
- Feature: Alternative shortcut for Find: Key_Slash
- Feature: unselectAll for scripts
- Bugfix: Move images when moving MCO
- Bugfix: Allow DeleteKeepChildren for MainBranches
- Bugfix: Smaller inc/dec of images
- Bugfix: Remove duplicate icon for opening linked vym maps in toolbar
- Bugfix: Reposition note flag after updating note
- Bugfix: Flags position after setting task sleep
- Bugfix: open LineEdit for heading at heading, not topLeft of BBox
- Bugfix: Toggling task flags
- Bugfix: Considering frame sizes
- Minor cleanups
- Remove redundant call to reposition
- Repriorizing FIXMEs
- Updated README
* Tue Jun  4 2013 uwedr@suse.de
- Version 2.3.18
- Bugfix: Double click branch while editing heading copies heading
- Bugfix: Remove duplicate icon for opening linked vym maps in toolbar
- Bugfix: setup for non-Linux OSs by Pino Toscano
- Bugfix: checks for VYM_DBUS instead of Q_OS_LINUX by Pino Toscano
- Feature: Enhanced documentation of vivym
- Feature: Show parent of a task in taskeditor
* Mon Apr  8 2013 uwedr@suse.de
- Version 2.3.17
- Feature: Template for creating snapshot in slideeditor
- Feature: Shortcut in scripteditor to "save to selected slide"
- Feature: Open vymLinks in background tab
- Feature: Open vymLinks in background tab
- Bugfix: Default size for PDF Export: A3
- Bugfix: Added missing note for automated test to git
- Bugfix: Editor key shortcuts for Save (Ctrl + S)
- Bugfix: Don't create duplicate UUIds while pasting
- Bugfix: #56 Default pdf viewer for Windows
- Bugfix: #45 Don't grab keyboard while editing heading
- Bugfix: #58 Notes break if they only contain whitespace
- Bugfix: Building on windows (Patrick Spendrin)
- Bugfix: Creating notes by piping mails (e.g. from mutt)
- Bugfix: LastExport for AO, ASCII, OrgMode, LaTeX
- Bugfix: Deselect task in TaskEditor, if no task selected in MapEditor
- Bugfix: Stretch width of last column in task editor
- Bugfix: Reuse previous HTML export settings
- Bugfix: (Regression) creating XLinks
- Bugfix: Reuse previous HTML export settings
- Bugfix: Delete slide deleted 2 slides at once
- Bugfix: Removed unneeded output in testscript
- Building without DBUS using qmake or cmake
- Do not use a WinAPI implementation for unzip (Patrick Spendrin)
- make building with dbus an option under windows
- more updates for cmake build system
- Remove msvc warning (Patrick Spendrin)
* Sat Feb 23 2013 uwedr@suse.de
- Version 2.3.14
- Bugfix: Stretch width of last column in task editor
- Bugfix: Delete slide deleted 2 slides at once
- Bugfix: Removed unneeded output in testscript
- Bugfix: Reuse previous HTML export settings
- Bugfix: Delete slide deleted 2 slides at once
- Bugfix: Undo of deleting mapcenter
* Mon Jan 21 2013 uwedr@suse.de
- Version 2.3.13
- Bugfix: Undo of deleting mapcenter (risk of dataloss)
    (including testcase)
* Mon Jan 14 2013 uwedr@suse.de
- Version 2.3.12
- Excerpts from gitlog:
    Bugfix: nextBranch missed the first branch
    Bugfix: hasScrolledParent
    Bugfix: exportLast for exportAO
    Bugfix: Endless loop in HTML export
    Bugfix: Enable context menu when clicking on path of xlink
    Bugfix: Include complete heading into HTML link again
    Bugfix: CSS handling
    Bugfix: Crash when opening all URLs in subtree
    Bugfix: stopsign is not in same group as hook (standard-status)
    Bugfix: Shrink/Grow image
    Bugfix: Allow again the loading of xml files.
    Bugfix: Improve Freemind/Freeplane import filter
    Bugfix: Selecting Xlinks
    Feature: Use flags in HTML export
    Feature: HTML export - table of contents
    Feature: Setting title of map and use in HTML export
    Feature: Centering some input dialogs under mouse
    Feature: Entering date (ISO or text) for sleep time
    Feature: Use Key_I to set "info" flag.
    Feature: Save macros in scripteditor
    Feature: Load macros into scripteditor
    Feature: exportLast is scriptable
    Feature: Taskeditor shows icon for status
    Feature: Better handling of CSS during HTML export
    Feature: History window is now a dockable PropertyEditor
    Feature: Property window is now a dockable PropertyEditor
    Feature: Improved A&O export
    Feature: Keyboard shortcuts for flags
    Remote control for slides (space and backspace)
    New french translation by Marc Sert
    Improved entering of dates for task sleep
    Include flags in URLs of HTML export
    Removed bookmark support for KDE3
    Resorted entries in export menu
    Improved URL handling, esp. for firefox
    Close buttons on tabs, based on a patch by Edward Wang
    New tasks have status 'morning' now
    Use <pre> for fixed font notes in HTML exports
    Removed empty lists in HTML export
    Disabled automatic adding of http to URLs
    Doc: Added screenshots
    Doc: Fixed error in xlink documentation
    Doc: Updated pdfs
* Sat Dec 29 2012 uwedr@suse.de
- Version 2.3.11
- Fixing sourceforge URL in makedist-vym
* Fri Dec 28 2012 uwedr@suse.de
- Version 2.3.10
* Fri Dec 21 2012 uwedr@suse.de
- Version 2.3.9
* Fri Nov  9 2012 uwedr@suse.de
- Version 2.3.5
* Wed Oct 31 2012 uwedr@suse.de
- Version 2.3.3
* Sun Aug 12 2012 uwedr@suse.de
- Version 2.3.1
* Thu Jul 12 2012 uwedr@suse.de
- Version 2.3.0
* Wed Jul  4 2012 uwedr@suse.de
- Version 2.2.4
- Bugfix release
* Wed Jul  4 2012 uwedr@suse.de
- Version 2.2.3
- Bugfix release
- Update of documentation (pdf)
* Fri Jun 29 2012 uwedr@suse.de
- Version 2.2.2, Bugfix release
* Wed Jun 13 2012 uwedr@suse.de
- Version 2.2.0
* Tue Jun 12 2012 uwedr@suse.de
- Version 2.1.13
* Wed Jun  6 2012 uwedr@suse.de
- Version 2.1.12
* Fri Apr 20 2012 uwedr@suse.de
- Version 2.1.11
* Fri Apr 13 2012 uwedr@suse.de
- Version 2.1.8
* Fri Apr 13 2012 uwedr@suse.de
- Version 2.1.7
* Tue Apr 10 2012 uwedr@suse.de
- Version 2.0.12
- On windows store settings local to app by Scott
- Windows patches by Patrick Spendrin
- Removed debug option
- Replaced most of remaining cout by qDebug
- Transparent background for vym icons
* Thu Apr  5 2012 uwedr@suse.de
- Version 2.0.11
- Bugfix: Increasing number of (unused) images in zipfile
* Wed Mar 28 2012 uwedr@suse.de
- Version 2.0.10
- Bugfix: gcc 4.7 by Andreas Jaeger
- Bugfix: Qt 4.8 compilation issue with setDirectory
- Feature: Czech translation by Pavel Fric
- Bugfix:  segmentation fault after deleting an xLink (vym-Bugs-3460040)
- Bugfix: Filename must not change when saving only part of map (vym-Bugs-3459882)
* Wed Dec 14 2011 uwedr@suse.de
- Version 2.0.6
- Bugfix: Disappearing Umlauts when changing locale
* Tue Nov 22 2011 uwedr@suse.de
- Version 2.0.5
- added Giovanni Sora also to credits list
* Fri Nov 18 2011 uwedr@suse.de
- Version 2.0.4
- added Italian by Giovanni Sora
* Mon Nov 14 2011 uwedr@suse.de
- Version 2.0.3
- added Interlingua by Giovanni Sora
* Fri Oct 21 2011 uwedr@suse.de
- Version 2.0.2
- Bugfix: ensure showing of complete LineEdit
* Sat Oct 15 2011 uwedr@suse.de
- Version 2.0.1
- Bugfix: Next iteratation to fix crash when closing tabs
* Fri Oct 14 2011 uwedr@suse.de
- Final 2.0.0 version
- Bugfix: Correcting version in documention
- Update Bugzilla helper script to newer Perl version
- Bugfix: Crash with partly undeleted xLinkItems dangling around
- Removed debugging output
* Fri Oct  7 2011 uwedr@suse.de
- Version 1.99.1 (beta of 2.0.0)
- Bugfix: Minor fix for URL icon
* Tue Sep 20 2011 uwedr@suse.de
- Version 1.99.0 (beta of 2.0.0)
- Bugfix: Lost frames when moving mapcenter up/down
* Thu Sep  1 2011 uwedr@suse.de
- Version 1.13.42
- Minor German translation update
- Bugfix: Improved panning when reaching edge of view during object move
- Bugfix: Wrong imagemap for URL flag in HTML export
* Thu Aug 25 2011 uwedr@suse.de
- Version 1.13.41
- Feature: Only show some toolbars for new users
- Feature: Selection history and new toolbar
- Bugfix: HTML export border of note
- Feature: Selection history (buttons, doc, ...)
- Updated german translation
- Bugfix: changedflag and imageSize in Exports
- Bugfix: Conflicting shortcuts for Alt-E
- Added stopsign to flaggroup with hook, cross, ...
- Moving Dialogs to GUI (MainWindow)
* Thu Aug 11 2011 uwedr@suse.de
- Version 1.13.39
- Feature: Scroll to selection after load
- Feature: Bigger dialog to enter URLs
- Bugfix: Flickering when mousewheel is used during snapback animation
- Bugfix: Crash when exiting vym and animation still running
- Bugfix: Avoid flickering in animation
- Bugfix: Import directory
- Documentation: Added targets
- Bugfix: Shortcut to remove children not working
- Bugfix: vymlink with relativ path. Also new icons and documentation for vymlinks
- Added commandline option -R to documentation
- Bugfix: Loading of multiple maps with non existent files
- Feature: New settings for animations
- Bugfix: Shortcut to delete children
- Bugfix: Crash when copying to new map
- Feature: Setting default font for a map
- Feature: Save/Restore last session
- Bugfix: Progress dialog during reload of map
- Bugfix: map import replace and undo of deleteKeepChildren
- Removed Cancel button in progressbar
- Bugfix: Possible segfault in bugagent
- Bugfix: undo for deleteKeepChildren (xLink handling still missing)
* Mon Jul 18 2011 uwedr@suse.de
- Version: 1.13.36
- Bugfix: Compiling with Qt 4.4 (SLE SP1)
- Bugfix: Drag&drop handling
- Added XLink type for future additions of types
- Cleanups for shortcuts
- Feature: Toolbars toggles in View menu
- Bugfix: Select parent when moving to target and there is no successor
- Bugfix: Lost frames when relinking branches
- Bugfix: Lost image in documentation
* Tue Jul  5 2011 uwedr@suse.de
- Version: 1.13.35
- Updating documentation to 1.13.35
- Added section on brainstorming to documentation
- Feature: Autolayout when finished editing heading
- Feature: Place new MapCenter in middle of existing ones
- Bugfixes: Don't change frame when relinking mapcenters, new default style for XLink
- Bugfix: Random position for new mapcenter
- Bugfix: Adding bottomline again when changing frametype for mapcenters
- Feature: Immediatly edit new mapcenter after adding
- Bugfix: Random position for new mainbranch
- Bugfix: Undo for moveUp/Down
- Bugfix: Documentation fix.
- Feature: Basic SVG support
* Wed Jun 29 2011 uwedr@suse.de
- Version 1.13.34
- Updating documentation to 1.13.33
- Updated demos
- Bugfix: Double clicking to edit heading while LineEdit is visible updated wrong heading
- Bugfix: Easier Bugzilla URL creation
- Bugfix: Undo of moving to target and relinking
- Updated manpage
* Mon Jun  6 2011 uwedr@suse.de
- Version 1.13.32
- Bugfix: Some minor improvements in exports
- Bugfix: Wrong orientation of mainbranches after load
- Bugfix: Hide attributes tab in branch property window
- Feature: Context menu to edit XLinks
* Mon May 23 2011 uwedr@suse.de
- Version 1.13.30
    Bugfix: Following xLinks from context menu
    Feature: Zoom with scrollwheel
* Fri May 13 2011 uwedr@suse.de
- Version 1.13.29
    Feature: Clickable xLinks
    Bugfix: Moving to hidden targets didn't hide moved branch
    Bugfix: typo in FileDialog
    Bugfix: Minor glitches in format menus
    Bugfix: Don't show xlinks with partly invisible parents after loading of a map
    Bugfix: Switch to already opened vymlinked map
    Bugfix: French .tex docs for lyx by (Stefan Husmann)
    Bugfix: Removed unneeded option from HTML export dialog
    Bugfix: Get bugzilla data for subtree not enabled
    Feature: Improved Bugzilla support
    Feature: Resorted exports in menu
    Bugfix: Shortcut lists improved
    Feature: Cloud computing enabled.
    Bugfix: Target flag updated
    Feature: Adding icons for targets in menus
* Thu Feb 17 2011 vym@insilmaril.de
- Version: 1.13.27
- Bugfix: HTML stylesheet not copied in export
* Tue Feb 15 2011 vym@insilmaril.de
- Version: 1.13.26
- Bugfix: Image export (exportLast)
- Bugfix: Image export (including all images now)
- Bugfix: OpenOffice export
* Fri Feb 11 2011 vym@insilmaril.de
- Bugfix: Open/Save wrong in many filedialogs
* Thu Feb 10 2011 vym@insilmaril.de
- Bugfix: SaveAs works again for non-existing files
- Bugfix: Saving images
* Wed Feb  9 2011 uwedr@suse.de
- Version 1.13.25
- Bugfix: Don't select while updating Bugzilla links automatically
* Tue Feb  8 2011 uwedr@suse.de
- Version 1.13.24
- Feature: German translation
* Mon Feb  7 2011 uwedr@suse.de
- Version 1.13.23
  97 Bugfixes since 1.12.0
  129 Features since 1.12.0
  For details see vym.changelog in tarball
* Fri Feb  4 2011 uwedr@suse.de
- Version: 1.13.22
* Mon Dec  6 2010 wstephenson@novell.com
- Fix incorrect mimetype definition
* Fri Dec  3 2010 uwedr@suse.de
- Version: 1.13.18
- Bugfix: Glob patterns in mime type file (KDE bug #257980)
* Wed Apr  7 2010 vym@insilmaril.de
- Version: 1.13.2
- Bugfix: Segfault when removing a map
- Bugfix: Fixed regression in HTML export, which could lead to dataloss
    (not unhiding branches which are hidden during export)
* Tue Mar 30 2010 vym@insilmaril.de
- Bugfix: Much improved overview of search results, now also for notes
* Tue Mar 23 2010 vym@insilmaril.de
- Feature: Added commandline options to list keyboard shortcuts
- Bugfix: (Regression) Scrolling with PageUp/Down disabled, moving
    branches instead
- Bugfix: update scene after load, required user interaction before
* Mon Mar 22 2010 vym@insilmaril.de
- Bugfix: Segfault when undoing deleting of MapCenter
- Bugfix: Workaround for Qt bug, where cursor of embedded QLineEdits
    in 2nd tab was not shown
- Bugfix: Icon of TreeEditor now shows correct state
* Thu Mar 18 2010 vym@insilmaril.de
- Version: 1.13.1   First pre-release of 1.13.0 to buildservice
* Wed Mar 17 2010 vym@insilmaril.de
- Bugfix: Enabled Qt 4.6: Removed QtAnimation Framework and fixed flags
* Tue Mar 16 2010 vym@insilmaril.de
- Feature: zoomFactor is saved and restored on load
* Mon Mar 15 2010 vym@insilmaril.de
- Bugfix: Several fixes for later autoLayout
* Wed Mar 10 2010 vym@insilmaril.de
- Bugfix: MainWindow::getModel() returns correct model now
- Bugfix: Better focus handling in FindWidget
* Tue Mar  9 2010 vym@insilmaril.de
- Bugfix: Regression in scrolling branches
* Mon Mar  8 2010 vym@insilmaril.de
- Feature: New widget to display all results of Find action.
    Also opened with CTRL-F once FindWidget is open
- Feature: loadNote and saveNote commands to allow changing of note
    from external
* Fri Feb 19 2010 vym@insilmaril.de
- Bugfix: Fixed regression of flags
* Wed Feb 17 2010 vym@insilmaril.de
- Bugfix: When pasting a heading into the LineEdit, newlines are removed
    to avoid broken rendering
* Wed Feb 17 2010 vym@insilmaril.de
- Feature: Novell Bugzilla now has extra flag
* Wed Feb 10 2010 vym@insilmaril.de
- Feature: Sort lexically backwards
* Tue Feb  9 2010 vym@insilmaril.de
- Bugfix: Relinking now keeps frametype
* Thu Jan 21 2010 vym@insilmaril.de
- Bugfix: Changes in NoteEditor update the Save flag visually
* Wed Jan 20 2010 vym@insilmaril.de
- Bugfix: New Progressbar while loading maps: One bar to count them,
    one bar to into colors grind them
* Thu Jan 14 2010 vym@insilmaril.de
- Feature: Very basic support to find duplicate URLs
* Wed Jan 13 2010 vym@insilmaril.de
- Feature: Added action to open all URLs in subtree, default
    is now to only open those, which don't have scrolled parent
* Tue Jan 12 2010 vym@insilmaril.de
- Bugfix: Restart a konqueror ofr opening of URLs, if needed
* Tue Jan  5 2010 vym@insilmaril.de
- Bugfix: Dropping URLs
* Mon Jan  4 2010 vym@insilmaril.de
- Bugfix: Branch didn't unscroll when deleting last child
- Feature: URL icons in image map of HTML export work now
* Tue Dec 15 2009 vym@insilmaril.de
- Bugfix: A&O report didn't show subitems
* Mon Dec 14 2009 vym@insilmaril.de
- Bugfix: Wrong tmp position when relinking a mainbranch
- Bugfix: Image export, also used in HTML export
* Mon Dec  7 2009 vym@insilmaril.de
- Feature: Following xLinks is now possible by clicking in the
    part of a branch near to beginning of branch (20 pixels)
- Feature: Added new flag for status "work in progress"
    (between green hook and red cross)
- Bugfix: Animation of branches (default off in MapEditor)
- Bugfix: Segfault when closing map (due clearing selection in
    VymModel::clear()  )
* Thu Dec  3 2009 vym@insilmaril.de
- Bugfix: Clicking the note flag opens the note editor again
* Tue Dec  1 2009 vym@insilmaril.de
- Bugfix: Undo of detach
* Thu Nov 26 2009 vym@insilmaril.de
- Bugfix: Regression in Undo
- Bugfix: Find didn't find stuff in previous part of tree
* Tue Nov 24 2009 vym@insilmaril.de
- Bugfix: Automatic scrolling to new selected items didn't work
    reliable when item had scrolled parents
* Wed Nov 11 2009 vym@insilmaril.de
- Bugfix: New map has mapcenter again
* Tue Nov 10 2009 vym@insilmaril.de
- Bugfix: Autodetection of textformat (ASCII vs. HTML)
- Bugfix: nextBranch failed with xLinks
* Fri Oct 30 2009 uwedr@suse.de
- Bugfix: Selection doesn't get lost when switching maps
* Wed Oct 28 2009 uwedr@suse.de
- Feature: Adding timestamp to branch
* Wed Oct 21 2009 uwedr@suse.de
- Feature: expand/collapse by one level in TreeEditor
- Bugfix: Process like webbrowser started by vym survive vym now
* Tue Oct  6 2009 uwedr@suse.de
- Bugfix: Export to OpenOffice.org
- Bugfix: BranchProp window
* Sat Aug  8 2009 uwedr@suse.de
- Feature: Selecting with cursor now remembers left & right of
  mapcenters. Also improved selections in deeper trees
- Bugfix: Selecting with cursor in MapEditor
* Thu Aug  6 2009 uwedr@suse.de
- Bugfix: Removed the "new" in new branches to allow easier copy & paste
* Wed Jul 22 2009 uwedr@suse.de
- Bugfix: relinking a branch to a scrolled branch doesn't unscroll
    anymore
- Bugfix: Importing KDE bookmarks with empty folders doesn't
    scroll these folders anymore
* Thu Jul 16 2009 uwedr@suse.de
- Version: 1.13.0
- Bugfix: Deleting an animated part no longer segfaults
* Wed Apr  8 2009 uwedr@suse.de
- Version: 1.12.2h
- Bugfix: autosave time was not read correctly from settings
* Mon Apr  6 2009 uwedr@suse.de
- Bugfix: mod copy ended in endless loop...
* Thu Apr  2 2009 uwedr@suse.de
- Feature: Added sverige translation
* Mon Mar 30 2009 uwedr@suse.de
- Version: 1.12.2g
- Bugfix: (Regression in 1.12.2f) Export Bookmarks to KDE 3
* Tue Mar 17 2009 uwedr@suse.de
- Version: 1.12.2f
- Bugfix: Import/Export bookmarks works now also on KDE 4
- Feature: Added traditional chinese translation
* Tue Mar 10 2009 uwedr@suse.de
- Version: 1.12.2e
- Bugfix: Don't check for changes in file, if map was closed already
* Tue Mar 10 2009 uwedr@suse.de
- Bugfix: Closing a modified map without saving and with autosave
  enabled made autosave writing an empty map and thus
  destroying the original file
* Wed Feb 25 2009 uwedr@suse.de
- Bugfix: Enabled multiple mapcenters for export to OpenOffice.org
* Mon Dec  8 2008 uwedr@suse.de
- Bugfix: Images linked to a scrolled branch were not hidden, if parent
    branch was scrolled
* Thu Dec  4 2008 uwedr@suse.de
- Bugfix: After inserting XML, still write as zipped vym
* Wed Nov 12 2008 uwedr@suse.de
- Bugfix: bnc#443173 - VYM doesn't save mapcenter's note
* Mon Oct  6 2008 uwedr@suse.de
- Bugfix: Updated chinese translation from Moligaloo
* Sun Oct  5 2008 uwedr@suse.de
- Version: 1.12.2
- Bugfix: No more segfault for "delete & keep childs" on MapCenter
* Sun Jul 27 2008 uwedr@suse.de
- Version: 1.12.1
* Sun Jul 27 2008 uwedr@suse.de
- Bugfix: Animation timer didn't stop after animation was done, which
    caused high load
* Thu Jul 17 2008 uwedr@suse.de
- Bugfix: Deleting an animated part no longer segfaults
- Bugfix: smaller image for export to elliminate pixel jitter on right
    side
* Fri Jul 11 2008 uwedr@suse.de
- Bugfix: bnc#407600 vym fails with non-ASCI characters in path names
* Sun Jun  8 2008 uwedr@suse.de
- Bugfix: bnc#396365 vym cannot load maps saved with Qt 4.4
* Wed May 14 2008 uwedr@suse.de
- Version: 1.12.0 RC 2
- Feature: Russian translation
* Wed May  7 2008 uwedr@suse.de
- Bugfix: bnc#327078
* Tue May  6 2008 uwedr@suse.de
- Version: 1.12.0
* Wed Apr 30 2008 uwedr@suse.de
- Version: 1.11.9
- Bugfix: Some minor code cleanup
* Thu Apr 10 2008 uwedr@suse.de
- Version: 1.11.8
- Feature: Copy to new map now also in branch context menu
* Thu Apr 10 2008 uwedr@suse.de
- Bugfix: New map is not autosaved, if no filename is known yet
* Tue Apr  8 2008 uwedr@suse.de
- Version: 1.11.7
- Bugfix: Hangup when find function did not find anything
* Thu Mar 13 2008 uwedr@suse.de
- Bugfix: vym no longer forgets that a map is zipped
* Sun Mar  9 2008 uwedr@suse.de
- Bugfix: Segfault when pressing Home or End on MapCenter
* Wed Mar  5 2008 uwedr@suse.de
- Bugfix: Broken paths to floatimages
* Wed Feb 27 2008 uwedr@suse.de
- Bugfix: Fixed some issues with autosave and regulard file checks
* Mon Feb 11 2008 uwedr@suse.de
- Version: 1.11.6
- Feature: vym now checks regulary if map has changed on disk and
    asks for reload if necessary
* Mon Jan 21 2008 uwedr@suse.de
- Bugfix: No more warning dialog for overwriting note, when note is
    empty
* Tue Jan  8 2008 uwedr@suse.de
- Version: 1.11.5
- Feature: Started to implement multiple MapCenters in one map
* Mon Jan  7 2008 uwedr@suse.de
- Bugfix: vym.pro includes french translation now
* Mon Dec 17 2007 uwedr@suse.de
- Bugfix: bnc#341952 corrupted positions of mainbranches after updating to
    newer vym
* Wed Dec 12 2007 uwedr@suse.de
- Bugfix: Overloaded key shortcut for Alt-N (Network and Next window)
* Tue Dec  4 2007 uwedr@suse.de
- Bugfix: Temporary hide stuff during export
- Bugfix: Save parts of map
* Mon Dec  3 2007 uwedr@suse.de
- Bugfix: (Maint.) Exchanged pre- and postscript in XHTML Export dialog
* Fri Nov  9 2007 uwedr@suse.de
- Version: 1.11.3
- Feature: Added patches for better windows support by Andrew Ng
* Tue Nov  6 2007 uwedr@suse.de
- Version: 1.11.2
- Feature: Split up helper functions, started to write attributes
* Tue Nov  6 2007 uwedr@suse.de
- Version: 1.11.1
- Bugfix: sort branches has undo/redo now
* Fri Oct 26 2007 uwedr@suse.de
- Bugfix: zip state is changed now, when a .xml is save as .vym
* Wed Oct 24 2007 uwedr@suse.de
- Feature: Improved ascii export
- Bugfix: Present flag now does not set down arrows any longer
* Tue Oct 23 2007 uwedr@suse.de
- Bugfix: included more <typeinfo> for compiling with new gcc 4.3
* Fri Oct 19 2007 uwedr@suse.de
- Version: 1.11.0
- Feature: Added patches from Till Maas for better path handling to ease
    integration into various operating systems
- Feature: Added patch from Till Maas to use xdg-open as default browser
- Feature: Added patch from ????? to sort branches lexically
- Feature: Added patches from Juha Ruotsalainen for compiling on win32
* Tue Oct 16 2007 uwedr@suse.de
- Bugfix: included <typeinfo> for compiling in beta
* Thu Oct  4 2007 uwedr@suse.de
- Version: 1.10.1
- Bugfix: Missing action for editing URL in context menu
- Bugfix: "Hide in Export" didn't work
* Tue Sep  4 2007 uwedr@suse.de
- Bugfix: xLinks were not loaded from previously saved maps
* Mon Aug 27 2007 uwedr@suse.de
- Bugfix: Find manual in /usr/share/doc/packages/vym
- Bugfix: Updated README.txt
* Mon Aug 20 2007 uwedr@suse.de
- Version: 1.10.0
- Bugfix: Added missing standard flag (one of the smileys got lost)
- Bugfix: Wrong parsing of relative positions after load of
    previously zoomed map
* Tue Jul 31 2007 uwedr@suse.de
- Bugfix: Smother parabel links (Alexander Rettig)
* Fri Jul 27 2007 uwedr@suse.de
- Version: 1.9.4
- Feature: Restructured internal handling of XML based maps
- Feature: Switched from QSimpleTextItem to QTextItem for Freemind
  support
* Mon Jul 23 2007 uwedr@suse.de
- Version: 1.9.3
- Feature: Import of Freemind maps
* Tue Jul 17 2007 uwedr@suse.de
- Version: 1.9.2
- Bugfix: Workaround for wrong XML generated by QT with in QRichText
    list items
- Bugfix: No output from <span> tags in ASCII export any longer
* Wed Jul 11 2007 uwedr@suse.de
- Version: 1.9.1
- Bugfix: Don't ask for directory in XML-based exports like
    KDE-bookmarks
* Wed Jul 11 2007 uwedr@suse.de
- Version: 1.9.0
- Feature: Extended fileformat with object IDs to ease export from
    tomboy to vym
- Feature: Completed german translation
- Feature: Center on selection with "."
- Feature: Most important exports can be scripted now
- Feature: Creating new map with selection as MapCenter
- Feature: Simple export to CSV spreadsheet
- Feature: Copy from past steps in history to current one
- Feature: Editing of frame attributes in branch property window
- Feature: autosave
- Feature: number of undo/redo levels can be changed in settings
- Feature: branch property window settings are saved
- Feature: Added basic macros and documentation
- Feature: Color of selection can be changed now
- Feature: Pen and brush for frames can be set
- Feature: Simple Editor for scripts
- Feature: Added syntax highlighting for editor
- Feature: Unscroll all now only affects selected subtree
- Feature: Modifier Modes now change cursor when CTRL is pressed
- Feature: vym opens spanish documentation, if locale is es*
- Feature: New Frame format
- Feature: Properties dialog for branches instead of context menu entries
- Feature: Only one history window for all editors. State is saved.
- Feature: Canvas ported to QT 4.2 GraphicsView
- Feature: Options to use AntiaAliasing and smooth pixmap
    transformations
- Feature: Thick links use polygons now, less objects in scene
- Feature: More undo commands (and fixes there)
- Feature: Note Editor completly based on QT4 now.
- Feature: Opening of all URLs in a subtree
- Feature: Opening of all vymLinks in a subtree
- Feature: Changed format of configuration file a bit (new file anyway
    with introduction of QT4)
- Feature: Toolbar Layout is saved now
- Feature: Moved floats in XML Export, e.g. XHTML  shows floatimages at
- Bugfix: auto-select/auto-edit new branches
- Bugfix: Visibility of BranchProperty window is saved now
- Bugfix: Undo/Redo dropping images into map
- Bugfix: Undo/Redo of copy/paste steps
- Bugfix: NoteEditor now appears on first click (not 2nd)
- Bugfix: Disable autosave while there are redos available
- Bugfix: After changing link color, that color is applied to all links
    now
- Bugfix: Pasting of FIOs
- Bugfix: No selection of branches while editing heading
- Bugfix: geometry of selection box gets updated while setting scroll or
    hide flag
- Bugfix: Possible segfault when redoing deleteChilds()
- Bugfix: autosave timeout now read from settings file
- Bugfix: Settings for historywindow correclty read now
- Bugfix: Closing property window toggle corresponding button
- Bugfix: Unscroll all childs has saveState now
- Bugfix: Invisible selection after switching mapeditor
- Bugfix: For frames the links always were drawn at bottom of heading
- Bugfix: BranchPropertyWindow updates when selection is changed
- Bugfix: Crash when trying to temporary link to floatimage
- Bugfix: Drawing error when temporary linking subtrees
- Bugfix: Import of KDE Bookmarks
- Bugfix: Export to KDE Bookmarks
- Bugfix: Export to XHTML
- Bugfix: Drag and Drop of URLs now only creates one branch
- Bugfix: Remember last directory before  ASCII/LaTeX export
- Bugfix: Editing in NoteEditor now updates actions (save) again
- Bugfix: Deleting last branch automatically unscrolls parent now
- Bugfix: Scroll/Unscroll has undo/redo now
- Bugfix: xml-parsing code simplified
- Bugfix: Fixed pretty annoying repositioning of view after editing a
    heading. (don't call show() before positioning in heading...)
- Bugfix: Wrong Cursors after pressing CTRL and inserting/relinking
- Bugfix: Save PNG images with quality 100 to workaround image problems
- Bugfix: Remember last directory before XML export
- Bugfix: move branch up/down calls scene()->update() now => much faster
- Bugfix: Relinking of floatimages undo/redo
- Bugfix: printing scales correctly again
- Bugfix: Drag & Drop (basically) works again
- Bugfix: Crash caused by BranchObj::getLastSelected
- Bugfix: Signal handling by changes in TextEditor: Much faster now
- Bugfix: printing is working again
- Bugfix: move up/down to next subtree is working again
- Bugfix: Flags are working again
- Bugfix: Floatimages have correct select box again
- Bugfix: Image format is saved with floatimage
- Bugfix: New recent file handling, fixes crash on Mac OS X
- Bugfix: Position of floatimages is saved again
- Bugfix: Position of floatimages survives adjustCanvasSize()
- Bugfix: Adding branch to scrolled branch unscroll the former
- Bugfix: More undo commands (removed saveStateComplete)
- Bugfix: No more hopping around of floats, when canvas is resized
    (by using relative positions for mainbranches. This might
  confuse parsing 1.8.56 documents with vym <= 1.8.1
- Bugfix: Mac - XSL stylesheets are found
- Bugfix: Mac - fonts are scaling
- Bugfix: Mac - hand cursor is shown correctly
- Bugfix: Undo/Redo moving floatimages
- Bugfix: Shortcuts for scrolling branches/removing branch
- Bugfix: update-bookmarks script is not only executed, but
    also found now...
- Bugfix: More undo/redo (move of floatimages, relinking of branches)
- Bugfix: More undo/redo commands
- Bugfix: Actions updated after moving a branch now
- Bugfix: vym refuses to start if vymTmpDir can't be created
- Bugfix: Editing headings now works both on Mac and Linux
  beginning of export now
- Bugfix: Floatimages internally are saved as png, preserving the alpha
    channel
- Bugfix: Fixed broken check for non-existent OO-export configuration
* Wed Jan  3 2007 stbinner@suse.de
- cleanup BuildRequires to fix build for < 10.1
* Thu Jul 13 2006 uwedr@suse.de
- Version: 1.8.1
- Bugfix: Fixed broken check for non-existent OO-export configuration
* Thu Jun 22 2006 uwedr@suse.de
- Version 1.8.0
- Feature: Added icon for creating a new branch to toolbar
- Feature: Opening of tabs in Firefox or Mozilla
- Feature: Documentation is up to date now
- Feature: More icons
- Feature: New environment variable VYMHOME
- Bugfix: Saving original filename of floatimages finally works
- Bugfix: Positioning of floatimages while adjusting canvas size (also
    optimized code a bit)
- Bugfix: Right click e.g. on URL Flag opened URL _and_ context menu
- Bugfix: Deleting selection works also if Delkey is disabled.
- Bugfix: Exclusive flags did not work properly.
- Bugfix: Wrong icon in texteditor for text underline
- Bugfix: Changed screenshots in docu to represent new look
- Bugfix: Fixed z-plane of floatimage. Images did hide flags.
- Bugfix: wrong paths in XHTML export (bnc#168033), caused by wrong
    vymBaseDir
* Wed Jun 21 2006 adrian@suse.de
- remove libdrm-devel to fix build for < 10.1 (not needed)
* Mon Apr 24 2006 uwedr@suse.de
- Version: 1.7.15
- Bugfix: wrong paths in XHTML export (bnc#168033), caused by wrong
    vymBaseDir
- Bugfix: Problem with vymlinks pointing to higher directories (bnc#159770)
- Bugfix: All exports support hiding of objects now
- Bugfix: exportDir in XHTML export is correctly saved in map and
    defaults to current directory
- Bugfix: Workaround QT problem, where QT writes invalid XML code by not
    escaping & in fontnames (bnc#62283)
- Bugfix: Images preview in filedialog works again. Seemed to be a QT
    issue when multiple fileselections were allowed.
- Bugfix: Canvas Size corrected when flag is toggled
- Bugfix: Include Images Vertically was not read from saved file
- Feature: More icons
- Feature: New environment variable VYMHOME
- Feature: New icons. Icons and flags are not longer linked statically.
- Feature: Konqueror can open URLs in new tabs now.
- Feature: Hide Export Flag lets you hide objects in exports
- Feature: Floatimages now are basically ornamented objects. They could
    have e.g. an URL later
- Feature: On error the XML Parser shows the line which is causing the
    error
- Feature: Added export to Taskjuggler. xslt by Matt.
- Feature: Include Images Horizontally
- Feature: rudimentary import mmaps
- Feature: Import KDE bookmarks
- Feature: Own class xsltproc for doing xml transformations
  Tue Jan 25 16:07:53 CET 2006 - uwedr
- Version 1.7.7
- Feature: Export to Open Office 2.x (Open Document) basically works
- Feature: Export to XHTML uses smaller icon for URLs now
  Wed Jan 18 13:29:52 CET 2006 - uwedr
- Feature: Multiple File selection while loading maps and images
  Tue Jan  3 12:20:08 CET 2006 - uwe
- Feature: Small optimization in zip/unzip functions
  Mon Jan  2 21:03:05 CET 2006 - uwe
- Feature: FATE support for URLs
  Wed Dec 28 12:09:59 CET 2005 - uwe
- Version 1.7.6
- Feature: Added idAttr to BranchObj::saveToDir
- Bugfix: FloatObjects now use hideLinkIfUnselected, no more drawing
  errors, if FO is selected (undefined link)
- Bugfix: FloatImages don't get lost during save after they have been
  relinked to new parent
- Bugfix: Editing heading of mapcenter now also corrects position
  Mon Oct 10 13:18:29 CEST 2005 - uwedr
- Bugfix: Copy/Paste was currently not possible for images. Now
  completly rewrote mechanism. Instead of invisible map now XML import
  is used (Multiple clipboards should be not difficult now)
  Mon Oct  3 10:33:09 CEST 2005 - uwe
- Bugfix: Added small fix from Khaled Ahmed needed for display of
  arabic languages
  Mon Sep 12 21:39:38 CEST 2005 - uwedr
- Version 1.7.5
- Feature: Currently 15 levels of undo (GUI to set value still missing)
- Feature: Experimental LaTeX Export (without headers and opions so far)
  Sun Sep  5 10:26:15 CEST 2005 - uwedr
- Version 1.7.4
- Feature: Link of a branch can be hidden, if object is not selected
- Bugfix: Zoomed map no longer "jumps around" when branch is selected
  or moved.
- Bugfix: TextEditor now has grey background again, if it is empty
- Bugfix: BranchObj no longer need to connect to TextEditor, BranchObj
  is no longer a QOBJECT
  Thu Sep  1 12:26:24 CEST 2005 - uwedr
- Bugfix: Some minor changes so that translations use arguments now
  instead of several calls to tr()
  Tue Aug 30 13:38:31 CEST 2005 - uwedr
- Bugfix: Fixed pasting vymlinks: Pasting a branch to a target in
  another map caused vym to go into an endless loop, if the vymlink of the
  branch pointed to the new map.
- Bugfix: Invisible floatimages (which have a scrolled parent) no longer
  can be selected
  Fri Aug 19 09:12:49 CEST 2005 - uwedr
- Feature: added debian subdirectory created by Steffen Joeris
- Feature: added license to new aboutwindow
  Tue Aug 16 19:22:56 CEST 2005 - jhilmer
- Bugfix: Fixed link handling in aboutdialog.
  Tue Aug 16 12:25:09 CEST 2005 - uwedr
- Feature: Added keyboard shortcut to reset zoom factor
- Bugfix: Added "..." to menu entries leading to another dialog
- Bugfix: The setting option "Delete Key" is working again
- Bugfix: A branch moved from left side to right had wrong orienation
  Tue Aug  2 09:59:24 CEST 2005 - uwedr
-  Bugfix: Heading sizes now correct after moving e.g. mainbranch to
  a branch
  Mon Aug  1 22:40:29 CEST 2005 - jhilmer
- Bugfix: Problems with closing of note editor when text was modified.
- Feature: Added subscript and superscript to note editor
  Thu Jul 28 11:57:38 CEST 2005
- Version 1.7.3
- Bugfix: Frames didn't become invisible if scrolled
  Thu Jul 28 11:57:38 CEST 2005
- Version 1.7.2
- Bugfix: if selection changed before undo, undo worked on wrong
  branch
- included math.h again to enable compiling with gcc4
  Mi Jul 27 17:27:14 CEST 2005
- Bugfix: if selection changed before undo, undo worked on wrong branch
  Mon Jul 25 22:22:21 CEST 2005
- Bugfix: changed MapEditor::undo and ::saveState to also save selection
  Di Jul 19 16:42:31 CEST 2005
- Version: 1.7.1
- Feature: Drag and Drop also for .vym and files (Jakob Hilmer)
- Feature: More speedup on moving/relinking branches
  Mi Jul 13 11:44:10 CEST 2005
- Drag and Drop also for URLs
  Di Jul 12 20:56:09 CEST 2005
- Version: 1.7.0
  Mon Jul  4 21:13:42 CEST 2005
- Version: 1.6.9
- Bugfix: TextEditor doesn't get minimized in KDE any longer (KDE-bug?)
  Tue Jun 14 11:43:44 CEST 2005
- Feature: printer name is saved in vymrc now
- Feature: added image drag/drop (by Jakob Hilmer)
- Bugfix: Importing map into new map now has correct (empty) filename
  2005-06-07
- Version: 1.6.8
- Feature: Dramatic speedup in some operations
  (e.g. move branch up/down) due to extended
  undo engine
  2005-05-27
- Version: 1.6.7
- Feature:Changed default pdf-reader for Mac OSX
- Bugfix: xLinks stopped working in 1.6.6
- Bugfix: drawing error when using modModeCopy
- Bugfix: replaced lrint by qRound for BSD port
  2005-05-23
- Version 1.6.6
- Feature: Exclusive standard flags
  2005-05-19
- Version: 1.6.5
- Feature: removing a branch and keeping its childs
- Feature: removing childs of a branch
- Feature: insert branch and make selection its child
- Feature: restructured branch context menu
    in a basic version (straight line)
- Feature: New shortcuts  for use on Mac OS X
- Feature: Importing directories generates vymlinks now
- Bugfix: Changing linkstyle now automatically redraws all
  links again
- Bugfix: Paste icon is disabled if clipboard is empty
  2005-04-15
- Version: 1.6.4
- Feature: xLinks (connection between 2 branches) works
    in a basic version (straight line)
  2005-03-30
- Version: 1.6.3
- Bugfix: Saving of selection to a vym part (.vyp)
- Bugfix: Closing the noteeditor by closing its window now
    also toggles the responding toolbar button. &
  2005-03-24
- Version: 1.6.2
- Feature: Introduced Modifier modes: color, link, copy
- Feature: Linking branches is basically possible, though it can't be
    edited/saved yet
  2005-01-30
- Version: 1.6.1
- Feature: Optimized moving of branches: much faster especially
    with huge subtrees
- Bugfix: Segfault when loading vym part
- Bugfix: ugly unitialized lines, when temporary drawn link
    was moved from a temporary parent back to canvas
  2004-12-14
- Version: 1.6.0
- Feature: Added saving of xhtml settings in map
  2004-12-13
- Version: 1.5.2
- Feature: Added Import of maps with two modes:
    add/replace
- Feature: Added export of part of maps
- Feature: Added joining of paragraphs in text editor
- Feature: Optimized undo: Only relevant parts are saved, which
    dramatically improves e.g. moving branches up/down in most maps
- Bugfix: QTextEdit generates invalid XML code, which could lead to a
    parse error, if font name contains a \&
- Bugfix: Wrong order of mainbranches in Export
- Bugfix: zip archive was not deleted before save, which could lead to
  much bigger files, e.g.  when working on older \vym maps or deleted
  images
- Bugfix: Printing in Texteditor
- Bugfix: Wrong URLs in xhtml output
- Bugfix: Segfault fixed at Cursor left/right in empty map
  2004-10-01
- Version: 1.5.1
- Feature: More options in xhtml export: external scripts
  2004-09-26
- Version: 1.5.0
- Public release of all changes since 1.4.1
- Feature: New function to replace paragraphs in note editor
  by linebreaks, this makes pasted text much nicer
- Feature: New option to toggle exporting of of floatimages
- Feature: z-plane of floatimages can be set (manually only)
- Bugfix: Wrong ordering of branches, if mainbranch is exactly left of
  center
  2004-09-24
- Version: 1.4.7
- Feature: New Export to XHTML (by Thomas Schraitle)
- Bugfix: vymLink
- Bugfix: spaces and dots in filenames
- Bugfix: Error message if xsltproc is not installed
  2004-09-15
- Version: 1.4.6
- Feature: New file format: notes are saved as part of the .xml file
- Feature: Note Editor supports Rich Text now.
- Feature: Parser now also nows {\tt standardflag} (all letters lowercase)
  2004-08-23
- Version: 1.4.5
- Feature: Correct handling of font size in Heading
  2004-07-29
- Version: 1.4.4
- Selecting with cursor now works between subtrees
- Bugfix: vymLink was set to temporary dir in 1.4.3
  2004-07-19
- Version: 1.4.3
- Optimisation: Reduced canvas objects by only creating objects for used
  flags
- Better visualization of moving branch above/below target
- Find Window informs with dialog, if the search failed
- System Flags are clickable now
- Reworked CSS and XST stylsheets (comments, indent, browser
  compatibility)
- vymLinks are shown in statusbar
- current directory is save
- Rewritten load/save to improve multimap handling and unzipped files
- Bugfix: vymLinks don't get deleted when Cancel is pressed
- Bugfix: Fixed a bunch of bugs in XSL for HTML export
- Bugfix: More toolbar buttons disabled, if action not possible
- Bugfix: Renaming .vymfile now works
- Bugfix: mapChanged set when toggling flags
- Bugfix: CTRL-N was used twice
- Bugfix: Del didn't work on floatimage
- Version: 1.4.2
- Bugfix: Float image could not be deleted
  2004-05-25
- Version: 1.4.1
- Bugfix: Color of branch not saved
- Bugfix: wrong path at HTML export
- Bugfix: map is not save with special characters in path
  2004-05-17
- Version: 1.4.0
- Ask for confirmation before opening
  a map in multiple editors
- Save state of note editor (visible/minimized)
- Export to HTML
- Author and Comment is saved in map
- Stats are shown in Edit MapInfo
- Changes for OS X port (QCursor, QContextMenuEvent)
- Bugfix: Fonts from note editor are save now
- Bugfix: invisible image when parent is scrolled
- Bugfix: Segfault pressing "enter" for floatimage
- Bugfix: Images can't be outside of exported area
  anymore.
- Bugfix: Filenames with blanks
- Bugfix: Old maplink is shown when editing maplink
- Bugfix: always show cursor while editing heading
  2004-04-16
- Version: 1.3.5
- Export map to dir
- Export to any of QTs image formats
- Also right side of selection is always visible now.
  2004-04-07
- Version: 1.3.4
- Load last maps in file menu
- save last image path for loading
- Also export standard flags to dir.
  2004-03-26
- Version: 1.3.3
- Enabled <br> in headings as manual linebreak
- Heading can be copied to URL
- Bugfix: GIFs are automatically converted to PNG now
  2004-03-26
- Version: 1.3.2
- Add and move branches above/below selection, Texteditor copy all,
  2004-03-25
- Version: 1.3.1
- Export to directory, changed naming in .vym
  2004-03-23
- Version: 1.3.0
- Bugfix: Check if map can be saved at all
  2004-03-22
- Version: 1.2.12
- Select image format before saving image
  2004-03-18
- Version: 1.2.11
-		Selecting mainbranches by up/down
-		Export ASCII (experimental)
-		Each map can be saved individually at quit
-		Bugfix: Opening VymLink crashes QT
-		Bugfix: 50\%% less objects on canvas
-		Bugfix: Ignoring LANG, now always written as UTF8
  2004-03-16
- Version: 1.2.10
- Sort Mainbranches by angle to y-axis
- Import directory structure
- Bugfix: Set FrameType of MapCenter while loading map
  2004-03-12
- Version: 1.2.9
- Jump to another vym map
- Mainbranches are alwas ordered clockwise
  2004-03-03
- Version: 1.2.8
- Change frame types in context menu
  2004-02-25
- Version: 1.2.7
- Copy / Paste and save Floatimages
  2004-02-24
- Version: 1.2.6
- Closing vym in KDE now asks for save, too
- Context menu for branches
- Selection is saved in .vym file
  2004-02-18
- Version: 1.2.5
- URLs to external links can be added
- All actions are deactived if not possible
  2004-02-16
- Version: 1.2.4
- Images: Can be loaded, saved, relinked to other parents
  2004-01-27
- Version: 1.2.3
- Zoom: Reset and finer steps shrinking/enlarging
  2004-01-27
- Version: 1.2.2
- Editing of links (style and color)
  2004-01-27
- Version: 1.2.1
- Bugfix: LineEdit when adding branch has correct position again.
  2004-01-23
- Version: 1.2.0
- Scrolled parts are automatically unscrolled when selected and scrolled
  again later.
- Bugfix: Save flag is updated when multiple maps are opened
- Bugfix: Moving of branches is faster and more accurat when adding to
  mapcenter
  2003-12-04
- Version: 1.1.7
- Bugfix: Remember filename of note in noteeditor
  2003-12-02
- Version: 1.1.6
- Find Text also in Notes.
  2003-11-07
- Version: 1.1.5
- Bugfix: Correct setting and positioning when relinking branches
  2003-11-03
- Version: 1.1.4
- Scroll mode added (folding of subtrees).
- Bugfix: Wrong position of linedit in zoomed view
  2003-10-09
- Version: 1.1.3
-		Added clear button in find window, bugfixes
  2003-10-07
- Version: 1.1.2
- Links can be colored with color of heading
  2003-09-26
- Version: 1.1.1
- Improved visualization of linking to new branch
  2003-09-25
- Version: 1.1.0
- Find Function
- Selection always stays in view
  2003-09-18
- Version: 1.0.1
- Find function scrolls to result now
- Bugfix: Adding branch with midmouse
- Bugfix: multiple repositioning of map, when noteeditor was changed
  (speedup)
- New Linestyles (still hardcoded)
  2003-09-16
- Version: 1.0.0
- First public stable release
- Version: 0.9.0
- added quick color picker (CTRL + Left Mouse)  ?
- Version: 0.8.0
- added automatic canvas resizer, removed manual resizing of canvas
- added settings option to paste text into new branch
- simplified code
- Added heart flag
- Choose and switch between fixed and variable width fonts
- note editor
- Fixed segfault caused by undo and a call of updateNoteFlag of note
  editor
- Added settings menu to configure autoselect and autoedit mode
- autoedit and autoselect mode
- Fixed ugly display problem with QT Palette (Klaas Freitag)
- Reduced temporary directories from 4 to 1
- Added wordwrap in printing of notes
- New toolbar buttons in texteditor
- Set background color
- Fixed bug: Flags in toolbar not updated when selecting map center
- Version: 0.7.0
- No more segfault, when an object is deleted while being edited
- Keep focus constant when zooming in/out
- Export as png graphic
- Keep Center of map where it is while zooming
- Added Standard Flags (Smiley, Hook, Stopsign, ...)
- MDI: Multi Document Interface enables working on several maps
  simultanously
- Enabled creating a new map via argument on commandline
- Changed file extension from .mmap to .vym
- noteeditor changes color, if empty or nothing is selected
- Changes in NoteEditor window are recognized by main window, too, thus
  preventing loosing data when quitting the program.
- Version: 0.6.0
- New rendering engine: Faster, no flickering
- Version: 0.5.0
-  Changed printing to use maximum space on paper
-  Note editor is hidden, too, when mapeditor is minimized
-  New (compressed) file format
- Version: 0.4.0
- Size of map is saved
- Multi Line Headings
- Reworked Rendering Engine: Much faster now.
- Reworked Undo: Much faster now.
- Enabled moving of map center
- Multi-line headings
- Version: 0.3.0
- Introduced Undo
- Fixed some bugs
- Version: 0.2.0
- Moving view of map improved:
- New handling (acrobat reader style)
- New mousepointer
- Several tools to color a map
- Version: 0.1.0
- Inital version, basic map layout
- Data is stored in XML
* Fri Jan 27 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Wed Jan 25 2006 uwedr@suse.de
- Version 1.7.7
- Feature: Export to Open Office 2.x (Open Document) basically works
- Feature: Export to XHTML uses smaller icon for URLs now
- Feature: Multiple File selection while loading maps and images
- Feature: Small optimization in zip/unzip functions
- Feature: FATE support for URLs
- Feature: Added idAttr to BranchObj::saveToDir
- Bugfix: FloatObjects now use hideLinkIfUnselected, no more drawing
  errors, if FO is selected (undefined link)
- Bugfix: FloatImages don't get lost during save after they have been
  relinked to new parent
- Bugfix: Editing heading of mapcenter now also corrects position
- Bugfix: Copy/Paste was currently not possible for images. Now
  completly rewrote mechanism. Instead of invisible map now XML import
  is used (Multiple clipboards should be not difficult now)
- Bugfix: Added small fix from Khaled Ahmed needed for display of
  arabic languages
- Feature: Currently 15 levels of undo (GUI to set value still missing)
- Feature: Experimental LaTeX Export (without headers and opions so far)
* Sat Jan 14 2006 schwab@suse.de
- Don't strip binaries.
* Thu Oct 20 2005 uwedr@suse.de
- Bugfix: Copying a branch to clipboard lead to loss of note.
- Bugfix: vymLink and URL for MapCenter were not saved
* Mon Oct 17 2005 uwedr@suse.de
- Removed extra qualification in xml.h
* Mon Sep  5 2005 uwedr@suse.de
- Version 1.7.4
- Feature: Link of a branch can be hidden, if object is not selected
- Bugfix: Zoomed map no longer "jumps around" when branch is selected
  or moved.
- Bugfix: TextEditor now has grey background again, if it is empty
- Bugfix: BranchObj no longer need to connect to TextEditor, BranchObj
  is no longer a QOBJECT
* Thu Sep  1 2005 uwedr@suse.de
- Bugfix: Some minor changes so that translations use arguments now
  instead of several calls to tr()
* Tue Aug 30 2005 uwedr@suse.de
- Bugfix: Fixed pasting vymlinks: Pasting a branch to a target in
  another map caused vym to go in an endless loop, if the vymlink of the
  branch pointed to the new map.
- Bugfix: Invisible floatimages (which have a scrolled parent) can
  no longer can be selected
* Fri Aug 19 2005 uwedr@suse.de
- Feature: added debian subdirectory created by Steffen Joeris
- Feature: added license to new aboutwindow
  Tue Aug 16 19:22:56 CEST 2005 - jhilmer
- Bugfix: Fixed link handling in aboutdialog.
* Tue Aug 16 2005 uwedr@suse.de
- Feature: Added keyboard shortcut to reset zoom factor
- Bugfix: Added "..." to menu entries leading to another dialog
- Bugfix: The setting option "Delete Key" is working again
- Bugfix: A branch moved from left side to right had wrong orienation
* Tue Aug  2 2005 uwedr@suse.de
-  Bugfix: Heading sizes now correct after moving e.g. mainbranch to
  a branch
  Mon Aug  1 22:40:29 CEST 2005 - jhilmer
- Bugfix: Problems with closing of note editor when text was modified.
- Feature: Added subscript and superscript to note editor
* Thu Jul 28 2005 uwedr@suse.de
- Version 1.7.3
- Bugfix: Frames didn't become invisible if scrolled
* Thu Jul 28 2005 uwedr@suse.de
- Version 1.7.2
- Bugfix: if selection changed before undo, undo worked on wrong
  branch
* Wed Jul 27 2005 ro@suse.de
- include math.h in linkablemapobj.cpp and misc.cpp
* Thu Jul 14 2005 uwedr@suse.de
- Version 1.7.0
* Fri Apr 15 2005 uwedr@suse.de
- Update to 1.6.4
- Compiles on gcc4 now
* Tue Feb  8 2005 joe@suse.de
- Change menu category
- Add .desktop files for KDE mimetypes
* Fri Jan 21 2005 uwedr@suse.de
- Update to 1.6.0
* Fri Jan  7 2005 adrian@suse.de
- fix build, qmake isn't anymore in $PATH by default
* Wed Sep 29 2004 uwedr@suse.de
- Bugfix: pdf documentation was not found
* Tue Sep 28 2004 uwedr@suse.de
- Bugfix: Import from old map generated unbreakable spaces (ugly)
- Bugfix: No warning message (even if set) before overwriting dirs (ugly)
* Sun Sep 26 2004 uwedr@suse.de
- Update to 1.5.0
* Fri May 28 2004 adrian@suse.de
- use "Development Design" Categories to match the menu definition (bnc#41338)
* Tue May 25 2004 uwedr@suse.de
- Bugfix: map is not saved with special characters in path
- Bugfix: color of branch not saved sometimes
- Bugfix: wrong path at HTML export
* Tue May 18 2004 uwedr@suse.de
- Bugfix: invisible image when parent is scrolled
- Bugfix: Segfault pressing "enter" for floatimage
- Bugfix: Images can't be outside of exported area anymore
- Bugfix: Filenames with blanks
- Bugfix: Old maplink is shown when editing maplink
- Bugfix: always show cursor while editing heading
* Tue Apr 27 2004 uwedr@suse.de
- Update to 1.4.0
* Tue Mar 23 2004 uwedr@suse.de
- Bugfix: New maps were not saved
- Bugfix: Check if file is writable before saving.
* Mon Mar 22 2004 uwedr@suse.de
- Update to 1.3.0
* Wed Feb 25 2004 hmacht@suse.de
- building as non-root user
* Thu Sep 18 2003 uwedr@suse.de
- Fixed bnc#31291   (drawing error, unnecessary files)
* Tue Sep 16 2003 uwedr@suse.de
- Update to 1.0.0
  + automatic resizing of canvas
  + Options
  + docs
  + Bugfixing
* Thu Jul 10 2003 uwedr@suse.de
- Update to 0.7.9:
  + graphical flags
  + export as png
  + fixed rare segfault
* Thu Jun  5 2003 uwedr@suse.de
- Initial version.
